@@ -12,7 +12,7 @@ use XTM::baseNameString;
 
 @ISA = qw(Exporter AutoLoader XTM::generic);
 @EXPORT = qw( );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 =pod
 
@@ -26,7 +26,28 @@ XTM::baseName - trivial class definition
 
 =head1 DESCRIPTION
 
-Generic container for accessor functions.
+Class covering a baseName
+
+=head2 Methods
+
+Following accessor methods are available via L<XTM::generic> (see that package how
+to set/add values):
+
+=over
+
+=item I<baseNameString>:
+
+I<$b>->baseNameString
+
+returns a L<XTM::baseNameString> node
+
+=item I<scope>:
+
+I<$b>->scope
+
+returns a L<XTM::scope> node
+
+=back
 
 =cut
 
@@ -51,10 +72,11 @@ L<XTM>
 
 =head1 AUTHOR INFORMATION
 
-Copyright 2001, Robert Barta <rho@telecoma.net>, All rights reserved.
- 
+Copyright 2001, 2002, Robert Barta <rho@telecoma.net>, All rights reserved.
+
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
+http://www.perl.com/perl/misc/Artistic.html
 
 =cut
 
